# pbn2html

convert pbn file to html

# Usage

````
pip install pbn2html
pbn2html "local.pbn"
````

## example

````

````

## snapshot

* 

# Development

````
# docker run -it  -v $PWD:/app  -w /app python:3.8  bash
# python3 -m pip install --user --upgrade twine wheel
# python3 setup.py sdist clean
# rm -rf dist
# python3 setup.py sdist bdist_wheel
# cat > ~/.pypirc
# python3 -m twine upload --skip-existing --verbose dist/*
````

# Reference

* http://www.tistis.nl/pbn/
* http://bridgecomposer.com/
